@@ -100,7 +100,7 @@ sub send {
 	my @MASK;
 	my $length = scalar @DECODED + 128;
 	if ($length > 256 || $mask) {
-		@MASK = (1, 1, 1, 1); # map { int(rand(256)) } 0 .. 3;
+		@MASK =  map { int(rand(256)) } 0 .. 3;
 		my $i;
 		for (@DECODED) {
 			push @ENCODED, $_ ^ $MASK[$i++ % 4];
@@ -166,7 +166,7 @@ Terse::WebSocket - Lightweight WebSockets
 
 =head1 VERSION
 
-Version 0.111
+Version 0.112
 
 =cut
 
