@@ -8,8 +8,12 @@ sub build_controller {
 	return $self;
 }
 
-sub hidden :get :path(app/hidden) :delayed {
+sub hidden :get :path(app/hidden) {
 	my ($self, $t) = @_;
+	unless ($t->plugin('validateparam')->az($t->params->name)) {
+		$t->raiseError('param name contains more than just A-Z', 500);
+		return 0;
+	}
 	$t->response->hits = '1';
 	$t->response->test = "kaput";
 }
